@@ -75,14 +75,13 @@ int main(int argc, char **argv)
     KDBusService dbssvc(KDBusService::Unique);
 
     QCommandLineParser parser;
-    parser.addHelpOption();
-    parser.addVersionOption();
 
+    aboutData.setupCommandLine(&parser);
     parser.addOption(QCommandLineOption(QStringLiteral("show"), i18n("Show window on startup")));
     parser.addOption(QCommandLineOption(QStringLiteral("kwalletd"), i18n("For use by kwalletd only")));
     parser.addOption(QCommandLineOption(QStringLiteral("name"), i18n("A wallet name")));
-
     parser.process(a);
+    aboutData.processCommandLine(&parser);
     KWalletManager wm;
     QObject::connect(&dbssvc, &KDBusService::activateRequested, &wm, &QWidget::activateWindow);
 
